@@ -4,52 +4,6 @@ from .base import Function
 from neurograd.nn.module import Module
 
 
-# CUPY MULTI-AXIS VAR BUG SLOWDOWN FIX
-def _reduce(arr, axis, reduction_func, keepdims=False, **kwargs):
-    """
-    Performs a reduction iteratively over a tuple of axes for optimal speed,
-    especially in CuPy. This function is the FAST PATH for decomposable
-    reductions like mean, sum, max, and min.
-    """
-    # If axis is None, reduce over all axes by converting to a tuple of all axes.
-    if axis is None:
-        axis = tuple(range(arr.ndim))
-    # If axis is a single integer, the library's default is already optimized.
-    if isinstance(axis, int):
-        return reduction_func(arr, axis=axis, keepdims=keepdims, **kwargs)
-    # --- Iterative Path for Tuple of Axes (The Fast Path) ---
-    ndim = arr.ndim
-    axes = tuple(ax if ax >= 0 else ndim + ax for ax in axis)
-    axes = tuple(sorted(axes, reverse=True))
-    result = arr
-    for ax in axes:
-        result = reduction_func(result, axis=ax, keepdims=True, **kwargs)
-    if not keepdims:
-        result = xp.squeeze(result, axis=axes)
-    return result
-
-def _iterative_var(arr, axis, keepdims=False):
-    """
-    Calculates variance correctly and quickly using the fast `_reduce` helper.
-    This version includes a clamp to prevent negative variance due to
-    floating-point inaccuracies (catastrophic cancellation).
-    """
-    arr_mean = _reduce(arr, axis, xp.mean, keepdims=True)
-    arr_sq_mean = _reduce(xp.square(arr), axis, xp.mean, keepdims=True)
-    var = arr_sq_mean - xp.square(arr_mean)
-    # --- THE FIX ---
-    # Clamp the variance to be non-negative. This is a robust way to
-    # handle floating-point errors without affecting correct positive variances.
-    var = xp.maximum(var, 0)
-    if not keepdims:
-        if axis is None:
-            axis_to_squeeze = tuple(range(arr.ndim))
-        elif isinstance(axis, int):
-            axis_to_squeeze = (axis,)
-        else: # tuple
-            axis_to_squeeze = axis
-        var = xp.squeeze(var, axis=axis_to_squeeze)
-    return var
 
 
 
