@@ -197,7 +197,23 @@ def maybe_log_op_memory(op_name: str, inputs: Iterable, output, timing_context=N
                 in_shapes.append(())
         out_shape = None
         try:
-            out_shape = tuple(getattr(output, "shape", ()))
+            # Handle single output
+            if hasattr(output, "shape"):
+                out_shape = tuple(getattr(output, "shape", ()))
+            # Handle multiple outputs (like backward passes)
+            elif isinstance(output, (tuple, list)):
+                out_shapes = []
+                for o in output:
+                    try:
+                        if o is not None:
+                            out_shapes.append(tuple(getattr(o, "shape", ())))
+                        else:
+                            out_shapes.append(None)
+                    except Exception:
+                        out_shapes.append(())
+                out_shape = out_shapes if len(out_shapes) > 1 else (out_shapes[0] if out_shapes else ())
+            else:
+                out_shape = ()
         except Exception:
             out_shape = ()
 
